package extension

import (
	"net/url"
	"strings"
)

// URL структура для хранения данных о переданном действии.
type ActionURL struct {
	*url.URL
}

// NewURL возвращает структуру ActionURL
func NewActionURL(action string) (*ActionURL, error) {
	u, err := url.Parse(action)
	if err != nil {
		return nil, err
	}
	return &ActionURL{URL: u}, nil
}

func (u *ActionURL) actionParts() (string, string) {
	splitPath := strings.Split(strings.TrimLeft(u.Path, "/"), "/")
	if u.URL != nil && u.URL.Scheme == "grpc" && len(splitPath) >= 2 {
		return splitPath[0], splitPath[1]
	}
	// for backwards compatibility
	if len(splitPath) == 1 {
		return "", splitPath[0]
	}
	return "", ""
}

func (u *ActionURL) Action() string {
	_, action := u.actionParts()
	return action
}

func (u *ActionURL) Extension() string {
	ext, _ := u.actionParts()
	return ext
}
