package members

import (
	"fmt"
	"strconv"
)

type Member struct {
	OrgId  string `bson:"orgId"`
	UserId string `bson:"userId"`
	Role   Role   `bson:"role"`
}

func (m Member) Clone() *Member {
	return &Member{
		OrgId:  m.OrgId,
		UserId: m.UserId,
		Role:   m.Role,
	}
}

type Role uint

const (
	NotMember Role = iota
	RoleMember
	RoleOwner
	RoleAdmin
)

func (r Role) IsPrivileged() bool {
	return r == RoleOwner || r == RoleAdmin
}

func (r Role) Format(s fmt.State, verb rune) {
	switch verb {
	case 's':
		_, _ = s.Write([]byte(r.String()))
	default:
		_, _ = s.Write([]byte(strconv.Itoa(int(r))))
	}
}

func (r Role) String() string {
	switch r {
	case NotMember:
		return "not member"
	case RoleMember:
		return "member"
	case RoleOwner:
		return "owner"
	case RoleAdmin:
		return "admin"
	}
	return fmt.Sprintf("%d", r)
}

func RoleFromString(r string) Role {
	switch r {
	case RoleMember.String():
		return RoleMember
	case RoleOwner.String():
		return RoleOwner
	case RoleAdmin.String():
		return RoleAdmin
	default:
		return NotMember
	}
}
